@@ -33,7 +33,7 @@ Variables::Variables(const Variables& v) : QHash<QString, Object*>(v)
 {
 	QHash<QString, Object*>::iterator i;
 	for (i = this->begin(); i != this->end(); ++i)
-		*i = Expression::objectCopy(*i);
+		*i = (*i)->copy();
 }
 
 Variables::~Variables()
@@ -61,13 +61,7 @@ void Variables::modify(const QString& name, const Object* o)
 	if(contains(name))
 		delete value(name);
 	
-	if(o->isContainer()) {
-		const Container* c=static_cast<const Container*>(o);
-		if(c->containerType()==Container::lambda)
-			m_functions.insert(name);
-	}
-	
-	insert(name, Expression::objectCopy(o));
+	insert(name, o->copy());
 }
 
 
@@ -92,7 +86,7 @@ bool Variables::destroy(const QString& s)
 
 void Variables::stack(const QString &name, const Object *o)
 {
-	insertMulti(name, Expression::objectCopy(o));
+	insertMulti(name, o->copy());
 }
 
 void Variables::stack(const QString & name, double n)
