@@ -359,6 +359,10 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
 
     Pos->TimeTransit->setText( QString().sprintf( "%02d:%02d", tt.hour(), tt.minute() ) );
     Pos->AltTransit->setText( talt.toDMSString() );
+
+    // Restore the position and other time-dependent parameters
+    selectedObject->recomputeCoords( ut, geo );
+
 }
 
 void DetailDialog::createLinksTab()
@@ -390,12 +394,12 @@ void DetailDialog::createLinksTab()
     connect( Links->RemoveLinkButton, SIGNAL(clicked()), this, SLOT( removeLinkDialog() ) );
 
     // When an item is selected in info list, selected items are cleared image list.
-    connect( Links->InfoTitleList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT( setCurrentLink(QListWidgetItem*) ) );
-    connect( Links->InfoTitleList, SIGNAL(itemClicked(QListWidgetItem*)), Links->ImageTitleList, SLOT( clearSelection() ) );
+    connect( Links->InfoTitleList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), this, SLOT( setCurrentLink(QListWidgetItem*) ) );
+    connect( Links->InfoTitleList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), Links->ImageTitleList, SLOT( clearSelection() ) );
 
     // vice versa
-    connect( Links->ImageTitleList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT( setCurrentLink(QListWidgetItem*) ) );
-    connect( Links->ImageTitleList, SIGNAL(itemClicked(QListWidgetItem*)), Links->InfoTitleList, SLOT( clearSelection() ));
+    connect( Links->ImageTitleList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), this, SLOT( setCurrentLink(QListWidgetItem*) ) );
+    connect( Links->ImageTitleList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), Links->InfoTitleList, SLOT( clearSelection() ));
 
     connect( Links->InfoTitleList, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT( viewLink() ) );
     connect( Links->ImageTitleList, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT( viewLink() ) );
@@ -477,10 +481,10 @@ void DetailDialog::updateLists()
     Links->ImageTitleList->clear();
 
     foreach ( const QString &s, selectedObject->InfoTitle() )
-    Links->InfoTitleList->addItem( s );
+        Links->InfoTitleList->addItem( s );
 
     foreach ( const QString &s, selectedObject->ImageTitle() )
-    Links->ImageTitleList->addItem( s );
+        Links->ImageTitleList->addItem( s );
 
     updateButtons();
 }
@@ -513,11 +517,10 @@ void DetailDialog::editLinkDialog()
 
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList )
     {
-        row = selectedObject->InfoTitle().indexOf( m_CurrentLink->text() );
-        if ( row < 0 ) return;
+        row = Links->InfoTitleList->row( m_CurrentLink );
 
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->InfoList()[row];
+        currentItemURL = selectedObject->InfoTitle().at( row );
         search_line = selectedObject->name();
         search_line += ':';
         search_line += currentItemTitle;
@@ -527,11 +530,10 @@ void DetailDialog::editLinkDialog()
     }
     else if ( m_CurrentLink->listWidget() == Links->ImageTitleList )
     {
-        row = selectedObject->ImageTitle().indexOf( m_CurrentLink->text() );
-        if ( row < 0 ) return;
+        row = Links->ImageTitleList->row( m_CurrentLink );
 
         currentItemTitle = m_CurrentLink->text();
-        currentItemURL   = selectedObject->ImageList()[row];
+        currentItemURL = selectedObject->ImageTitle().at( row ); 
         search_line = selectedObject->name();
         search_line += ':';
         search_line += currentItemTitle;
@@ -608,7 +610,7 @@ void DetailDialog::removeLinkDialog()
 
     if ( m_CurrentLink->listWidget() == Links->InfoTitleList )
     {
-        row = selectedObject->InfoTitle().indexOf( m_CurrentLink->text() );
+        row = Links->InfoTitleList->row( m_CurrentLink );
         currentItemTitle = m_CurrentLink->text();
         currentItemURL   = selectedObject->InfoList()[row];
         LineEntry = selectedObject->name();
@@ -620,7 +622,7 @@ void DetailDialog::removeLinkDialog()
     }
     else if ( m_CurrentLink->listWidget() == Links->ImageTitleList )
     {
-        row = selectedObject->ImageTitle().indexOf( m_CurrentLink->text() );
+        row = Links->ImageTitleList->row( m_CurrentLink );
         currentItemTitle = m_CurrentLink->text();
         currentItemURL   = selectedObject->ImageList()[row];
         LineEntry = selectedObject->name();
