@@ -371,12 +371,11 @@ void MainWindow::setupActions()
 	actionCollection()->addAction("console", console);
 	connect(console, SIGNAL(execute(const QString&)), this, SLOT(execute(const QString&)));
 
-
-	QAction *executeConsole = actionCollection()->addAction("execute_console");
-	executeConsole->setIcon(KIcon("go-jump-locationbar"));
-	executeConsole->setText(i18n("Execute"));
-	connect(executeConsole, SIGNAL(triggered()), console, SLOT(executeActionTriggered()));
-	executeConsole->setWhatsThis(i18n("Execute: Executes the current line in the console"));
+	executeConsoleAct = actionCollection()->addAction("execute_console");
+	executeConsoleAct->setIcon(KIcon("go-jump-locationbar"));
+	executeConsoleAct->setText(i18n("Execute"));
+	connect(executeConsoleAct, SIGNAL(triggered()), console, SLOT(executeActionTriggered()));
+	executeConsoleAct->setWhatsThis(i18n("Execute: Executes the current line in the console"));
 
 	// Help menu actions
 	//TODO: implement context help
@@ -764,6 +763,8 @@ void MainWindow::run()
 	}
 	editor->disable();
 	console->disable();
+	executeConsoleAct->setEnabled(false);
+
 	// start parsing (always in full speed)
 	iterationTimer->setSingleShot(false);
 	iterationTimer->start(0);
@@ -876,6 +877,7 @@ void MainWindow::abort()
 
 	editor->enable();
 	console->enable();
+	executeConsoleAct->setEnabled(true);
 
 	if (interpreter->encounteredErrors()) {
 		errorDialog->setErrorList(interpreter->getErrorList());
