@@ -7,6 +7,7 @@
 //
 // Copyright 2007      Torsten Rahn <tackat@kde.org>"
 // Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2009      Jens-Michael Hoffmann <jensmh@gmx.de>
 //
 
 //
@@ -14,23 +15,27 @@
 //
 
 
-#ifndef __MARBLE__HTTPDOWNLOADMANAGER_H
-#define __MARBLE__HTTPDOWNLOADMANAGER_H
+#ifndef MARBLE_HTTPDOWNLOADMANAGER_H
+#define MARBLE_HTTPDOWNLOADMANAGER_H
 
 
 #include <QtCore/QString>
 #include <QtCore/QUrl>
 #include <QtCore/QList>
+#include <QtCore/QSet>
 #include <QtCore/QStack>
+#include <QtCore/QQueue>
 
 #include "marble_export.h"
 
+class QTimer;
+
 namespace Marble
 {
 
 class HttpJob;
 class StoragePolicy;
-class MarbleNetworkPlugin;
+class NetworkPlugin;
 
 /*
  * @Short This class manages scheduled downloads. 
@@ -76,6 +81,11 @@ class MARBLE_EXPORT HttpDownloadManager : public QObject
      */
     void setActivatedJobsLimit( int activatedJobsLimit );
 
+    /**
+     * Switches loading on/off, useful for offline mode.
+     */
+    void setDownloadEnabled( const bool enable );
+
     StoragePolicy* storagePolicy() const;
 
  public Q_SLOTS:
@@ -97,11 +107,33 @@ class MARBLE_EXPORT HttpDownloadManager : public QObject
 
  Q_SIGNALS:
     void downloadComplete( QString, QString );
-    void statusMessage( QString );
+
+    /**
+     * This signal is emitted if a file is downloaded and the data argument
+     * contains the files content. The HttpDownloadManager takes care to save
+     * it using the given storage policy.
+     * This is experimental and needs more testing.
+     */
+    void downloadComplete( QByteArray data, QString initiatorId );
+
+    /**
+     * Signal is emitted when a new job is added to the queue.
+     */
+    void jobAdded();
+
+    /**
+     * Signal is emitted when a job is removed from the queue.
+     * The job might be completed or blacklisted.
+     */
+    void jobRemoved();
+
 
  private Q_SLOTS:
     void activateJobs();
     void reportResult( Marble::HttpJob *job, int id );
+    void requeue();
+    void jobRedirected( HttpJob *job, QUrl newLocation );
+    void jobDataReceived( HttpJob *job, QByteArray data );
 
  private:
     Q_DISABLE_COPY( HttpDownloadManager )
@@ -110,6 +142,12 @@ class MARBLE_EXPORT HttpDownloadManager : public QObject
     HttpJob          *createJob( const QUrl& sourceUrl, const QString& destFileName,
                                  const QString &id );
 
+    /**
+     * Helper method for activateJobs(), also used in handling of redirections,
+     * where the new job should be activated imediately.
+     */
+    void activateJob( HttpJob * const job );
+
     /**
      * Helper method for the public addJob methods which contains shared code.
      */
@@ -117,9 +155,13 @@ class MARBLE_EXPORT HttpDownloadManager : public QObject
 
     bool              m_downloadEnabled;
 
+    QTimer           *m_requeueTimer;
     QStack<HttpJob*>  m_jobQueue;
+    QQueue<HttpJob*>  m_waitingQueue;
     QList<HttpJob*>   m_activatedJobList;
-    QList<HttpJob*>   m_jobBlackList;
+
+    /// Contains the blacklisted source urls
+    QSet<QString>     m_jobBlackList;
 
     int               m_activatedJobsLimit;
     int               m_jobQueueLimit;
@@ -127,9 +169,9 @@ class MARBLE_EXPORT HttpDownloadManager : public QObject
     QUrl              m_serverUrl;
     StoragePolicy    *m_storagePolicy;
 
-    MarbleNetworkPlugin *m_networkPlugin;
+    NetworkPlugin    *m_networkPlugin;
 };
 
 }
 
-#endif // __MARBLE__HTTPDOWNLOADMANAGER_H
+#endif // MARBLE_HTTPDOWNLOADMANAGER_H
