@@ -11,8 +11,12 @@
 #ifndef MARBLEPLACEMARKMODEL_P_H
 #define MARBLEPLACEMARKMODEL_P_H
 
-#include <QtCore/QDebug>
+#include <QtCore/QChar>
 #include <QtCore/QRegExp>
+#include <QtCore/QString>
+
+namespace Marble
+{
 
 namespace GeoString
 {
@@ -28,5 +32,6 @@ namespace GeoString
         return result;
     }
 }
+}
 
 #endif
