@@ -11,14 +11,14 @@
 
 #include "GeoDataPolyStyle.h"
 
+namespace Marble
+{
+
 class GeoDataPolyStylePrivate
 {
   public:
     GeoDataPolyStylePrivate()
-    {
-    }
-
-    ~GeoDataPolyStylePrivate()
+     : m_fill( true ), m_outline( true )
     {
     }
 
@@ -29,12 +29,17 @@ class GeoDataPolyStylePrivate
 };
 
 GeoDataPolyStyle::GeoDataPolyStyle()
-    : d (new GeoDataPolyStylePrivate )
+    : d( new GeoDataPolyStylePrivate )
+{
+}
+
+GeoDataPolyStyle::GeoDataPolyStyle( const GeoDataPolyStyle& other )
+    : GeoDataColorStyle( other ), d( new GeoDataPolyStylePrivate( *other.d ) )
 {
 }
 
 GeoDataPolyStyle::GeoDataPolyStyle( const QColor &color )
-    : d (new GeoDataPolyStylePrivate )
+    : d( new GeoDataPolyStylePrivate )
 {
     setColor( color );
 }
@@ -44,6 +49,13 @@ GeoDataPolyStyle::~GeoDataPolyStyle()
     delete d;
 }
 
+GeoDataPolyStyle& GeoDataPolyStyle::operator=( const GeoDataPolyStyle& other )
+{
+    GeoDataColorStyle::operator=( other );
+    *d = *other.d;
+    return *this;
+}
+
 void GeoDataPolyStyle::setFill( const bool &fill )
 {
     d->m_fill = fill;
@@ -79,3 +91,5 @@ void GeoDataPolyStyle::unpack( QDataStream& stream )
     stream >> d->m_fill;
     stream >> d->m_outline;
 }
+
+}
