@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlcolorTagHandler : public GeoTagHandler {
-public:
-    KmlcolorTagHandler();
-    virtual ~KmlcolorTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlcolorTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlcolorTagHandler_h
