@@ -27,8 +27,8 @@
 #include "vocabulary/containermodel.h"
 #include "vocabulary/lessonmodel.h"
 #include "vocabulary/wordtypemodel.h"
-#include "vocabulary/leitnerview.h"
-#include "vocabulary/leitnermodel.h"
+//#include "vocabulary/leitnerview.h"
+//#include "vocabulary/leitnermodel.h"
 
 #include "entry-dialogs/multiplechoicewidget.h"
 #include "entry-dialogs/comparisonwidget.h"
@@ -88,14 +88,20 @@ Editor::~Editor()
     saveMainWindowSettings(cfg);
 }
 
+void Editor::updateScriptMenu()
+{
+    m_scriptManager->reloadActions();
+}
+
 void Editor::updateDocument()
 {
 ///@todo we can use connect here
+    m_vocabularyView->setDocument(m_mainWindow->parleyDocument()->document());
     m_vocabularyModel->setDocument(m_mainWindow->parleyDocument()->document());
 
     m_lessonModel->setDocument(m_mainWindow->parleyDocument()->document());
     m_wordTypeModel->setDocument(m_mainWindow->parleyDocument()->document());
-    m_leitnerModel->setDocument(m_mainWindow->parleyDocument()->document());
+//    m_leitnerModel->setDocument(m_mainWindow->parleyDocument()->document());
 
     if (!m_mainWindow->parleyDocument()->document()) {
         return;
@@ -106,7 +112,7 @@ void Editor::updateDocument()
     m_wordTypeView->expandToDepth(0);
 
     // the top level container of this model only holds the others
-    m_leitnerView->setRootIndex(m_leitnerModel->index(0,0));
+//    m_leitnerView->setRootIndex(m_leitnerModel->index(0,0));
 
     connect(m_mainWindow->parleyDocument()->document(), SIGNAL(docModified(bool)), m_mainWindow, SLOT(slotUpdateWindowCaption()));
     connect(m_vocabularyModel, SIGNAL(documentChanged(KEduVocDocument*)),
@@ -125,7 +131,6 @@ void Editor::updateDocument()
 //     new ModelTest(m_vocabularyModel, this);
 }
 
-
 void Editor::initDockWidgets()
 {
 // Lesson dock
@@ -184,27 +189,27 @@ void Editor::initDockWidgets()
         m_wordTypeView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Leitner boxes dock
-    QDockWidget* leitnerDockWidget = new QDockWidget(i18n("Grade Boxes"), this);
-    leitnerDockWidget->setObjectName( "LeitnerDock" );
-    m_leitnerView = new LeitnerView(this);
-    leitnerDockWidget->setWidget(m_leitnerView);
-    addDockWidget( Qt::LeftDockWidgetArea, leitnerDockWidget );
-    m_dockWidgets.append(leitnerDockWidget);
+//    QDockWidget* leitnerDockWidget = new QDockWidget(i18n("Grade Boxes"), this);
+//    leitnerDockWidget->setObjectName( "LeitnerDock" );
+//    m_leitnerView = new LeitnerView(this);
+//    leitnerDockWidget->setWidget(m_leitnerView);
+//    addDockWidget( Qt::LeftDockWidgetArea, leitnerDockWidget );
+//    m_dockWidgets.append(leitnerDockWidget);
 
-    m_leitnerModel = new LeitnerModel(this);
-    leitnerDockWidget->setVisible(false);
-    actionCollection()->addAction("show_leitner_dock", leitnerDockWidget->toggleViewAction());
+//    m_leitnerModel = new LeitnerModel(this);
+//    leitnerDockWidget->setVisible(false);
+//    actionCollection()->addAction("show_leitner_dock", leitnerDockWidget->toggleViewAction());
 
-    m_leitnerView->setModel(m_leitnerModel);
+//    m_leitnerView->setModel(m_leitnerModel);
 
-    connect(m_leitnerView, SIGNAL(selectedLeitnerBoxChanged(KEduVocLeitnerBox*)),
-        m_vocabularyModel, SLOT(setLeitnerBox(KEduVocLeitnerBox*)));
+//    connect(m_leitnerView, SIGNAL(selectedLeitnerBoxChanged(KEduVocLeitnerBox*)),
+//        m_vocabularyModel, SLOT(setLeitnerBox(KEduVocLeitnerBox*)));
 
-    connect(m_leitnerView, SIGNAL(signalShowContainer(KEduVocContainer*)),
-        m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
+//    connect(m_leitnerView, SIGNAL(signalShowContainer(KEduVocContainer*)),
+//        m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
 
-    connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        m_leitnerView, SLOT(setTranslation(KEduVocExpression*, int)));
+//    connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
+//        m_leitnerView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Conjugations
     QDockWidget *conjugationDock = new QDockWidget(i18n("Conjugation"), this);
@@ -320,7 +325,7 @@ void Editor::initDockWidgets()
 // Summary word
     QDockWidget *summaryDock = new QDockWidget(i18n("Summary"), this);
     summaryDock->setObjectName("SummaryDock");
-    m_summaryWordWidget = new SummaryWordWidget(m_vocabularyModel, m_mainWindow->parleyDocument()->document(), this);
+    m_summaryWordWidget = new SummaryWordWidget(m_vocabularyFilter, m_mainWindow->parleyDocument()->document(), this);
     summaryDock->setWidget(m_summaryWordWidget);
     addDockWidget(Qt::RightDockWidgetArea, summaryDock);
     actionCollection()->addAction("show_summary_dock", summaryDock->toggleViewAction());
@@ -431,7 +436,7 @@ void Editor::initActions()
     showStatistics->setIcon(KIcon("view-statistics"));
     showStatistics->setText(i18n("&Statistics..."));
     connect(showStatistics, SIGNAL(triggered(bool)), m_mainWindow, SLOT(slotShowStatistics()));
-    showStatistics->setWhatsThis(i18n("Show and reset statistics for the current collection"));
+    showStatistics->setWhatsThis(i18n("Show statistics for the current collection"));
     showStatistics->setToolTip(showStatistics->whatsThis());
     showStatistics->setStatusTip(showStatistics->whatsThis());
 
@@ -544,6 +549,7 @@ void Editor::initScripts()
 
     //Load scripts
     m_scriptManager->loadScripts();
+    m_scriptManager->reloadScripts();
 }
 
 ParleyMainWindow* Editor::mainWindow()
@@ -553,7 +559,7 @@ ParleyMainWindow* Editor::mainWindow()
 
 void Editor::slotLanguageProperties()
 {
-    LanguageProperties properties(m_mainWindow->parleyDocument()->document(), this);
+    LanguageProperties properties(m_mainWindow->parleyDocument(), this);
     if ( properties.exec() == KDialog::Accepted ) {
          m_vocabularyModel->resetLanguages();
     }
